summaryrefslogtreecommitdiffstats
path: root/ksysguard/gui/WorkSheet.cc
diff options
context:
space:
mode:
Diffstat (limited to 'ksysguard/gui/WorkSheet.cc')
-rw-r--r--ksysguard/gui/WorkSheet.cc32
1 files changed, 16 insertions, 16 deletions
diff --git a/ksysguard/gui/WorkSheet.cc b/ksysguard/gui/WorkSheet.cc
index 8d53edb6b..c7cac3127 100644
--- a/ksysguard/gui/WorkSheet.cc
+++ b/ksysguard/gui/WorkSheet.cc
@@ -73,7 +73,7 @@ WorkSheet::WorkSheet( uint rows, uint columns, uint interval, TQWidget* parent,
// Initialize worksheet with dummy displays.
for ( uint r = 0; r < mRows; ++r )
for ( uint c = 0; c < mColumns; ++c )
- replaceDisplay( r, c );
+ tqreplaceDisplay( r, c );
mGridLayout->activate();
@@ -159,14 +159,14 @@ bool WorkSheet::load( const TQString &fileName )
return false;
}
- replaceDisplay( row, column, element );
+ tqreplaceDisplay( row, column, element );
}
// Fill empty cells with dummy displays
for ( uint r = 0; r < mRows; ++r )
for ( uint c = 0; c < mColumns; ++c )
if ( !mDisplayList[ r ][ c ] )
- replaceDisplay( r, c );
+ tqreplaceDisplay( r, c );
setModified( false );
@@ -276,7 +276,7 @@ void WorkSheet::paste()
}
TQDomElement element = doc.documentElement();
- replaceDisplay( row, column, element );
+ tqreplaceDisplay( row, column, element );
}
void WorkSheet::setFileName( const TQString &fileName )
@@ -319,7 +319,7 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const TQString &hostName,
}
/* If the by 'row' and 'column' specified display is a TQGroupBox dummy
* display we replace the widget. Otherwise we just try to add
* the new sensor to an existing display. */
if ( mDisplayList[ row ][ column ]->isA( "DummyDisplay" ) ) {
KSGRD::SensorDisplay* newDisplay = 0;
@@ -362,7 +362,7 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const TQString &hostName,
return 0;
}
- replaceDisplay( row, column, newDisplay );
+ tqreplaceDisplay( row, column, newDisplay );
}
mDisplayList[ row ][ column ]->addSensor( hostName, sensorName, sensorType, sensorDescr );
@@ -447,17 +447,17 @@ void WorkSheet::dropEvent( TQDropEvent *e )
}
/* Find the sensor display that is supposed to get the drop
* event and replace or add sensor. */
for ( uint r = 0; r < mRows; ++r )
for ( uint c = 0; c < mColumns; ++c )
- if ( mDisplayList[ r ][ c ]->geometry().contains( e->pos() ) ) {
+ if ( mDisplayList[ r ][ c ]->tqgeometry().tqcontains( e->pos() ) ) {
addDisplay( hostName, sensorName, sensorType, sensorDescr, r, c );
return;
}
}
}
-TQSize WorkSheet::sizeHint() const
+TQSize WorkSheet::tqsizeHint() const
{
return TQSize( 200,150 );
}
@@ -471,7 +471,7 @@ void WorkSheet::customEvent( TQCustomEvent *e )
}
}
-bool WorkSheet::replaceDisplay( uint row, uint column, TQDomElement& element )
+bool WorkSheet::tqreplaceDisplay( uint row, uint column, TQDomElement& element )
{
TQString classType = element.attribute( "class" );
KSGRD::SensorDisplay* newDisplay;
@@ -501,12 +501,12 @@ bool WorkSheet::replaceDisplay( uint row, uint column, TQDomElement& element )
if ( !newDisplay->restoreSettings( element ) )
return false;
- replaceDisplay( row, column, newDisplay );
+ tqreplaceDisplay( row, column, newDisplay );
return true;
}
-void WorkSheet::replaceDisplay( uint row, uint column, KSGRD::SensorDisplay* newDisplay )
+void WorkSheet::tqreplaceDisplay( uint row, uint column, KSGRD::SensorDisplay* newDisplay )
{
// remove the old display at this location
delete mDisplayList[ row ][ column ];
@@ -531,7 +531,7 @@ void WorkSheet::replaceDisplay( uint row, uint column, KSGRD::SensorDisplay* new
mDisplayList[ row ][ column ]->show();
}
- setMinimumSize(sizeHint());
+ setMinimumSize(tqsizeHint());
setModified( true );
}
@@ -544,7 +544,7 @@ void WorkSheet::removeDisplay( KSGRD::SensorDisplay *display )
for ( uint r = 0; r < mRows; ++r )
for ( uint c = 0; c < mColumns; ++c )
if ( mDisplayList[ r ][ c ] == display ) {
- replaceDisplay( r, c );
+ tqreplaceDisplay( r, c );
setModified( true );
return;
}
@@ -563,7 +563,7 @@ void WorkSheet::createGrid( uint rows, uint columns )
mRows = rows;
mColumns = columns;
- // create grid layout with specified dimentions
+ // create grid tqlayout with specified dimentions
mGridLayout = new TQGridLayout( this, mRows, mColumns, 5 );
mDisplayList = new KSGRD::SensorDisplay**[ mRows ];
@@ -612,7 +612,7 @@ void WorkSheet::resizeGrid( uint newRows, uint newColumns )
for ( r = 0; r < newRows; ++r )
for ( c = 0; c < newColumns; ++c )
if ( r >= mRows || c >= mColumns )
- replaceDisplay( r, c );
+ tqreplaceDisplay( r, c );
/* set stretch factors for new rows and columns (if any) */
for ( r = mRows; r < newRows; ++r )
@@ -319,7 +319,7 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const TQString &hostName,
}
/* If the by 'row' and 'column' specified display is a TQGroupBox dummy
- * display we replace the widget. Otherwise we just try to add
+ * display we tqreplace the widget. Otherwise we just try to add
* the new sensor to an existing display. */
if ( mDisplayList[ row ][ column ]->isA( "DummyDisplay" ) ) {
@@ -447,17 +447,17 @@ void WorkSheet::dropEvent( TQDropEvent *e )
}
/* Find the sensor display that is supposed to get the drop
- * event and replace or add sensor. */
+ * event and tqreplace or add sensor. */
for ( uint r = 0; r < mRows; ++r )
for ( uint c = 0; c < mColumns; ++c )